@@ -30,7 +30,7 @@ package Apache2::WURFLFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "1.21";
+  $VERSION= "1.31";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -57,6 +57,7 @@ package Apache2::WURFLFilter;
   my $repasshanlder=0;
   my $globalpassvariable="";
   my $log4wurfl="";
+  my $xml_config="false";
   
   $ImageType{'png'}="png";
   $ImageType{'gif'}="gif";
@@ -72,6 +73,9 @@ package Apache2::WURFLFilter;
   # Check if MOBILE_HOME is setting in apache httpd.conf file for example:
   # PerlSetEnv MOBILE_HOME <apache_directory>/MobileFilter
   #
+  if ($ENV{XML_CONFIG}) {
+     $xml_config=$ENV{XML_CONFIG};
+  } 
   printLog("WURFLFilter Version $VERSION");
   if ($ENV{MOBILE_HOME}) {
 	  &loadConfigFile("$ENV{MOBILE_HOME}/WURFLFilterConfig.xml","$ENV{MOBILE_HOME}/wurfl.xml");
@@ -89,101 +93,201 @@ sub loadConfigFile {
 	     my $capability;
 	     my $r_id;
 	     my $dummy;
-		 if (-e "$file") {
-			 printLog("Start loading  WURFLMobile.config");
-			 open (IN, "$file");
-				 while (<IN>) {
-					 if ($_ =~ /\<capability\>/o) {
-						$capability=extValueTag('capability',$_);
-						$Capability{$capability}=$capability;			  
-					 }
-					 if ($_ =~ /\<MobileVersionUrl\>/o) {
-						$mobileversionurl=extValueTag('MobileVersionUrl',$_);
-					 }			
-					 if ($_ =~ /\<IntelliSwitch\>/o) {
-						$intelliswitch=extValueTag('IntelliSwitch',$_);
-					 }
-					 if ($_ =~ /\<XHTMLUrl/o) {
-						$capability=extValueTag('XHTMLUrl',$_);
-						($null,$val,$null2)=split(/\"/, $_);
-						$XHTMLUrl{$val}=$capability;				   
-					 }				
-					 if ($_ =~ /\<WMLUrl/o) {
-						$capability=extValueTag('WMLUrl',$_);
-						($null,$val,$null2)=split(/\"/, $_);
-						$WMLUrl{$val}=$capability;				   
-					 }				
-					 if ($_ =~ /\<CHTMLUrl/o) {
-						$capability=extValueTag('CHTMLUrl',$_);
-						($null,$val,$null2)=split(/\"/, $_);
-						$CHTMLUrl{$val}=$capability;				   
-					 }				
-					
-					 if ($_ =~ /\<FullBrowserUrl\>/o) {
-						$fullbrowserurl=extValueTag('FullBrowserUrl',$_);
-					 }			
-					 if ($_ =~ /\<CookieSet\>/o) {
-						$cookieset=extValueTag('CookieSet',$_);
-						printLog("CookieSet is:           $cookieset");
-					 }			
-					 if ($_ =~ /\<PassQueryStringSet\>/o) {
-						$querystring=extValueTag('PassQueryStringSet',$_);
-						printLog("PassQueryStringSet is : $querystring");
-					 }			
-					 if ($_ =~ /\<ShowDefaultVariable\>/o) {
-						$showdefaultvariable=extValueTag('ShowDefaultVariable',$_);
-						printLog("ShowDefaultVariable is: $showdefaultvariable");
-					 }			
-					 if ($_ =~ /\<WurflNetDownload\>/o) {
-						$wurflnetdownload=extValueTag('WurflNetDownload',$_);
-						printLog("WurflNetDownload is:    $wurflnetdownload");
+	     if ($xml_config eq 'true') {
+			 if (-e "$file") {
+				 printLog("Start loading  WURFLMobile.config");
+				 open (IN, "$file");
+					 while (<IN>) {
+						 if ($_ =~ /\<capability\>/o) {
+							$capability=extValueTag('capability',$_);
+							$Capability{$capability}=$capability;			  
+						 }
+						 if ($_ =~ /\<MobileVersionUrl\>/o) {
+							$mobileversionurl=extValueTag('MobileVersionUrl',$_);
+						 }			
+						 if ($_ =~ /\<IntelliSwitch\>/o) {
+							$intelliswitch=extValueTag('IntelliSwitch',$_);
+						 }
+						 if ($_ =~ /\<XHTMLUrl/o) {
+							$capability=extValueTag('XHTMLUrl',$_);
+							($null,$val,$null2)=split(/\"/, $_);
+							$XHTMLUrl{$val}=$capability;
+							printLog("XHTMLUrl is: width=$val and URL=$capability");
+						 }				
+						 if ($_ =~ /\<WMLUrl/o) {
+							$capability=extValueTag('WMLUrl',$_);
+							($null,$val,$null2)=split(/\"/, $_);
+							$WMLUrl{$val}=$capability;	
+							printLog("WMLUrl is: width=$val and URL=$capability");
+						 }				
+						 if ($_ =~ /\<CHTMLUrl/o) {
+							$capability=extValueTag('CHTMLUrl',$_);
+							($null,$val,$null2)=split(/\"/, $_);
+							$CHTMLUrl{$val}=$capability;
+							printLog("CHTMLUrl is: width=$val and URL=$capability");
+						 }				
 						
-					 }			
-					 if ($_ =~ /\<DownloadWurflURL\>/o) {
-						$downloadwurflurl=extValueTag('DownloadWurflURL',$_);
-					 }			
-					 if ($_ =~ /\<DownloadZipFile\>/o) {
-						$downloadzipfile=extValueTag('DownloadZipFile',$_);
-						printLog("DownloadZipFile is:     $downloadzipfile");
-					 }
-					 if ($_ =~ /\<ConvertImage\>/o) {
-						$convertimage=extValueTag('ConvertImage',$_);
-						printLog("ConvertImage is :       $convertimage");
-					 }			
-					 if ($_ =~ /\<ResizeImageDirectory\>/o) {
-						$resizeimagedirectory=extValueTag('ResizeImageDirectory',$_);
-					 }			
-					 if ($_ =~ /\<WebAppConvertImages\>/o) {
-						$virtualdirectoryimages=extValueTag('WebAppConvertImages',$_);
-						printLog("WebAppConvertImages is: $virtualdirectoryimages");
-					 }	
-					 
-					 if ($_ =~ /\<WebAppDirectory\>/o) {
-						$virtualdirectory=extValueTag('WebAppDirectory',$_);
-					 }			
-					 if ($_ =~ /\<ConvertOnlyImages\>/o) {
-						$convertonlyimages=extValueTag('ConvertOnlyImages',$_);
-						printLog("ConvertOnlyImages is:   $convertonlyimages");
-					 }	
-					 if ($_ =~ /\<Log4WurflNoDeviceDetect\>/o) {
-						$log4wurfl=extValueTag('Log4WurflNoDeviceDetect',$_);
-					 }	
+						 if ($_ =~ /\<FullBrowserUrl\>/o) {
+							$fullbrowserurl=extValueTag('FullBrowserUrl',$_);
+						 }			
+						 if ($_ =~ /\<CookieSet\>/o) {
+							$cookieset=extValueTag('CookieSet',$_);
+							printLog("CookieSet is:           $cookieset");
+						 }			
+						 if ($_ =~ /\<PassQueryStringSet\>/o) {
+							$querystring=extValueTag('PassQueryStringSet',$_);
+							printLog("PassQueryStringSet is : $querystring");
+						 }			
+						 if ($_ =~ /\<ShowDefaultVariable\>/o) {
+							$showdefaultvariable=extValueTag('ShowDefaultVariable',$_);
+							printLog("ShowDefaultVariable is: $showdefaultvariable");
+						 }			
+						 if ($_ =~ /\<WurflNetDownload\>/o) {
+							$wurflnetdownload=extValueTag('WurflNetDownload',$_);
+							printLog("WurflNetDownload is:    $wurflnetdownload");
+							
+						 }			
+						 if ($_ =~ /\<DownloadWurflURL\>/o) {
+							$downloadwurflurl=extValueTag('DownloadWurflURL',$_);
+						 }			
+						 if ($_ =~ /\<DownloadZipFile\>/o) {
+							$downloadzipfile=extValueTag('DownloadZipFile',$_);
+							printLog("DownloadZipFile is:     $downloadzipfile");
+						 }
+						 if ($_ =~ /\<ConvertImage\>/o) {
+							$convertimage=extValueTag('ConvertImage',$_);
+							printLog("ConvertImage is :       $convertimage");
+						 }			
+						 if ($_ =~ /\<ResizeImageDirectory\>/o) {
+							$resizeimagedirectory=extValueTag('ResizeImageDirectory',$_);
+						 }			
+						 if ($_ =~ /\<WebAppConvertImages\>/o) {
+							$virtualdirectoryimages=extValueTag('WebAppConvertImages',$_);
+							printLog("WebAppConvertImages is: $virtualdirectoryimages");
+						 }	
+						 
+						 if ($_ =~ /\<WebAppDirectory\>/o) {
+							$virtualdirectory=extValueTag('WebAppDirectory',$_);
+						 }			
+						 if ($_ =~ /\<ConvertOnlyImages\>/o) {
+							$convertonlyimages=extValueTag('ConvertOnlyImages',$_);
+							printLog("ConvertOnlyImages is:   $convertonlyimages");
+						 }	
+						 if ($_ =~ /\<Log4WurflNoDeviceDetect\>/o) {
+							$log4wurfl=extValueTag('Log4WurflNoDeviceDetect',$_);
+						 }	
+	
+						 
+	
+				 }				
+				 
+			 } else {
+			   printLog("File $file not found");
+			   ModPerl::Util::exit();
+			  }
+			  close IN;
+	      } else {
+	      	#The filter
+	      	printLog("Start read configuration from httpd.conf");
+	      	 if ($ENV{MobileVersionUrl}) {
+				$mobileversionurl=$ENV{MobileVersionUrl};
+				printLog("MobileVersionUrl is: $mobileversionurl");
+			 }	
+	      	 if ($ENV{IntelliSwitch}) {
+				$intelliswitch=$ENV{IntelliSwitch};
+				printLog("IntelliSwitch is: $intelliswitch");
+			 }	
+	      	 if ($ENV{FullBrowserUrl}) {
+				$fullbrowserurl=$ENV{FullBrowserUrl};
+				printLog("FullBrowserUrl is: $fullbrowserurl");
+			 }	
+	      	 if ($ENV{CookieSet}) {
+				$cookieset=$ENV{CookieSet};
+				printLog("CookieSet is: $cookieset");
+			 }	
+	      	 if ($ENV{PassQueryStringSet}) {
+				$querystring=$ENV{PassQueryStringSet};
+				printLog("PassQueryStringSet is: $querystring");
+			 }	
+	      	 if ($ENV{ShowDefaultVariable}) {
+				$showdefaultvariable=$ENV{ShowDefaultVariable};
+				printLog("ShowDefaultVariable is: $showdefaultvariable");
+			 }	
+	      	 if ($ENV{WurflNetDownload}) {
+				$wurflnetdownload=$ENV{WurflNetDownload};
+				printLog("WurflNetDownload is: $wurflnetdownload");
+			 }	
+	      	 if ($ENV{DownloadWurflURL}) {
+				$downloadwurflurl=$ENV{DownloadWurflURL};
+				printLog("DownloadWurflURL is: $downloadwurflurl");
+			 }	
+	      	 if ($ENV{DownloadZipFile}) {
+				$downloadzipfile=$ENV{DownloadZipFile};
+				printLog("DownloadZipFile is: $downloadzipfile");
+			 }	
+	      	 if ($ENV{ConvertImage}) {
+				$convertimage=$ENV{ConvertImage};
+				printLog("ConvertImage is: $convertimage");
+			 }	
+	      	 if ($ENV{ResizeImageDirectory}) {
+				$resizeimagedirectory=$ENV{ResizeImageDirectory};
+				printLog("ResizeImageDirectory is: $resizeimagedirectory");
+			 }	
+	      	 if ($ENV{WebAppConvertImages}) {
+				$virtualdirectoryimages=$ENV{WebAppConvertImages};
+				printLog("WebAppConvertImages is: $virtualdirectoryimages");
+			 }	
+	      	 if ($ENV{WebAppDirectory}) {
+				$virtualdirectory=$ENV{WebAppDirectory};
+				printLog("WebAppDirectory is: $virtualdirectory");
+			 }	
+	      	 if ($ENV{ConvertOnlyImages}) {
+				$convertonlyimages=$ENV{ConvertOnlyImages};
+				printLog("ConvertOnlyImages is: $convertonlyimages");
+			 }	
+	      	 if ($ENV{Log4WurflNoDeviceDetect}) {
+				$log4wurfl=$ENV{Log4WurflNoDeviceDetect};
+				printLog("Log4WurflNoDeviceDetect is: $log4wurfl");
+			 }	
+	      	 if ($ENV{CapabilityList}) {
+				my @dummycapability = split(/,/, $ENV{CapabilityList});
+				foreach $dummy (@dummycapability) {
+				      $Capability{$dummy}=$dummy;
+				      printLog("Capability is: $dummy");
+				}
+			 }	
+	      	 if ($ENV{XHTMLUrl}) {
+				my @dummyxurl = split(/,/, $ENV{XHTMLUrl});
+				foreach $dummy (@dummyxurl) {
+				      ($val, $capability)=split(/\|/, $dummy);
+				      $XHTMLUrl{$val}=$capability;
+				      printLog("XHTMLUrl is: width=$val and URL=$capability");
+				}
+			 }	
+	      	 if ($ENV{CHTMLUrl}) {
+				my @dummycurl = split(/,/, $ENV{CHTMLUrl});
+				foreach $dummy (@dummycurl) {
+				      ($val, $capability)=split(/\|/, $dummy);
+				      $CHTMLUrl{$val}=$capability;
+				      printLog("CHTMLUrl is: width=$val and URL=$capability");
+				}
+			 }	
+	      	 if ($ENV{WMLUrl}) {
+				my @dummywurl = split(/,/, $ENV{WMLUrl});
+				foreach $dummy (@dummywurl) {
+				      ($val, $capability)=split(/\|/, $dummy);
+				      $WMLUrl{$val}=$capability;
+				      printLog("WMLUrl is: width=$val and URL=$capability");
+				}
+			 }	             
 
-                     
-
-			 }				
-			 
-		 } else {
-		   printLog("File $file not found");
-		   ModPerl::Util::exit();
 	      }
-	      close IN;
           if ($log4wurfl eq "") {
    		     printLog("The parameter Log4WurflNoDeviceDetect must be defined into WURFLMobile.config");
 		     ModPerl::Util::exit();
 	      }
 	      
-	    printLog("Finish loading  WURFLMobile.config");
+	    printLog("Finish loading  parameter");
 	    printLog("----------------------------------");
 	    if ($wurflnetdownload eq "true") {
 	        printLog("Start downloading  WURFL.xml from $downloadwurflurl");
